package cn.wisenergy.web.admin.controller.app;

import cn.wisenergy.common.utils.R;
import cn.wisenergy.model.dto.UserInfoDto;
import cn.wisenergy.model.vo.AccountLoginVo;
import cn.wisenergy.model.vo.UserVipCommitVo;
import cn.wisenergy.model.vo.UserVipQueryVo;
import cn.wisenergy.service.app.StaffUserVipService;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.*;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

@RestController
@Api(tags = "员工端")
@RequestMapping("/staffUser")
@Slf4j
public class StaffUserVipController {
    @Autowired
    private StaffUserVipService staffUserVipService;

    @ApiOperation(value = "员工登录",notes = "员工登录",httpMethod = "POST")
    @ApiModelProperty(name = "loginVo",value = "登录信息",dataType = "AccountLoginVo")
    @PostMapping("/login")
    public R<Boolean> login(@RequestBody AccountLoginVo loginVo){
        log.info("StaffUserVipController[].login[].input.param:"+loginVo);

        return staffUserVipService.staffLogin(loginVo);
    }

    @ApiOperation(value = "添加Vip客户",notes = "添加Vip客户",httpMethod = "POST")
    @ApiModelProperty(name = "userVipCommitVo",value = "vip客户信息",dataType = "UserVipCommitVo")
    @PostMapping("/add")
    public R<Boolean> addUserVip(@RequestBody UserVipCommitVo userVipCommitVo){
        log.info("StaffUserVipController[].addUserVip[].input.param:"+userVipCommitVo);

        return staffUserVipService.addUserVip(userVipCommitVo);
    }

    @ApiOperation(value = "添加Vip客户(当客户已存在时)",notes = "添加Vip客户(当客户已存在时)",httpMethod = "POST")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "staffId", value = "员工id", dataType = "int"),
            @ApiImplicitParam(name = "phone", value = "vip客户手机号", dataType = "string")
    }
    )
    @PostMapping("/add2")
    public R<Boolean> addUserVipByPhone(Integer staffId, String phone){
        log.info("StaffUserVipController[].addUserVipByPhone[].input.param:"+staffId,phone);

        return staffUserVipService.addUserByPhone(staffId,phone);
    }

    @ApiOperation(value = "查询Vip客户",notes = "查询Vip客户",httpMethod = "POST")
    @ApiModelProperty(name = "queryVo",value = "vip客户信息",dataType = "UserVipQueryVo")
    @PostMapping("/getList")
    public R<PageInfo<UserInfoDto>> getUserVipList(@RequestBody UserVipQueryVo queryVo){
        log.info("StaffUserVipController[].addUserVip[].input.param:"+queryVo);

        return staffUserVipService.getList(queryVo);
    }
}
